# Le courant électrique

Dans les précédents chapitres, nous avons étudié les charges *statiques* (au repos). Ici, nous 
allons nous intéresser aux au mouvement des charges, plus communément appelés courants électriques.

Les courants électriques sont omniprésents dans notre vie quotidienne: ils servent à allumer les 
ampoules, faire fonctionner les ordinateurs (et plus globalement les engins électriques), etc. 
Les courants électriques se produisent en général à l'intérieur de fils conducteurs.
Afin de déplacer ces charges, il est également nécessaire qu'elles soient soumises à un champs
électrique. Hors dans les chapitres précédents, nous avons vu qu'à l'intérieur
d'un conducteur le champs électrique *est nul*. 
Cela pourrait sembler paradoxal, mais dans le cas des courants électriques, les charges
sont *en mouvement* (contrairement à ce qui se passait dans le chapitre précédent où
on étudiait ce qui se passait dans le cas *statique*). 
Ainsi quand les charges bougent, un champs électrique est présent à l'intérieur du conducteur,
et il est même nécessaire pour faire bouger les charges. Afin de contrôler ce champs
électrique, nous pouvons donc utiliser le champs électrique ou le potentiel électrique
(aussi appelé voltage dans la vie quotidienne). La différence de potentielle nécessaire
peut être produite à l'aide d'une batterie par exemple (ou une centrale nucléaire).

## La batterie électrique et son fonctionnement en 5min

Inspiré par des travaux sur les muscles des pattes de grenouilles qui se contractaient quand on
on les touchait avec des métaux différents, M. Volta inventa la batterie (en 1800).
La batterie produit un *courant électrique* en transformant
de l'énergie *chimique* en énergie *électrique*. Nous décrivons ici une batterie simplifiée, 
pour illustrer leur fonctionnement général. Deux *électrodes* (des tiges ou des plaques 
métalliques) sont plongées dans une solution appelée *électrolyte* (voir @fig:battery). Ce système s'appelle une
*cellule électrique* et en connectant plusieurs cellules on obtient une batterie (en fait une
cellule suffit de nos jours).

![Schéma d'une batterie. Deux électrodes, une positive et l'autre négative sont plongées dans un électrolyte.](figs/battery.svg){#fig:battery width=50%}

L'électrolyte dissout l'électrode négative (-), ses constituants en se dissolvant "abandonnent" des électrons et forment des *ions* (atomes chargés) positivement. Ainsi, l'électrolyte se charge positivement ce qui a pour effet d'arracher des atomes sur l'électrode positive (+). Il y a donc
une différence de charge entre les deux électrode et on crée ainsi une différence de potentiel
entre les 2 électrodes. Comme vu dans le chapitre précédent on peut utiliser cette différence de
potentiel pour mettre les charges en mouvement.

La @fig:source représente la notation pour la source de tension (batterie ou toute autre source)

![Le symbole pour la source de tension.](figs/source.svg){#fig:source width=10%}

## Le courant électrique

En connectant les deux électrode avec une fil conducteur, on construit un circuit électrique.
Ce circuit peut contenir tout un tas d'autres choses comme par exemple une ampoule (led parce
qu'elles consomment moins). Dans le circuit les charges peuvent se déplacer librement,
et donnent ainsi lieu à un *courant électrique*. Le courant électrique, $I$, est définit comme
la variation de charge ($\Delta Q$) pendant un certain laps de temps ($\Delta t$) donné
$$
I=\frac{\Delta Q}{\Delta t}.
$$
Les unités de $I$ sont les *ampères*, notées, $[\A]$

---

Question (Conversion d'unités) # 

Comment exprime-t-on les unités du courant en fonction d'autres unités vues précédemment dans ce cours?

---

---

Réponse (Conversion d'unités) # 

Le courant électrique étant donné par une charge divisée par un temps on a

$$
[\A]=\left[\frac{\C}{\mathrm{t}}\right].
$$

---

Un courant électrique ne peut passer qu'à condition qu'un chemin continu existe pour faire passer le courant. S'il y a une discontinuité le courant ne peut pas passer (voir @fig:circuit).

![Un exemple de circuit simple avec un appareil électrique (une ampoule par exemple).](figs/circuit.svg){#fig:circuit width=50%}

Dans le cas d'un courant continu, le courant est le même à n'importe quel point d'un circuit fermé. Ce fait est la conséquence de la conservation de la charge: la batterie ou un appareil électrique ne détruisent ni ne créent de charges nettes.


---

Exemple (Charge totale dans un circuit) #

Imaginons qu'un courant continu de $2.5\ \A$ passe dans un circuit pendant 5 minutes. Quelle est la charge totale qui est passée dans le circuit? Combien d'électrons cela fait?

---

---

Solution (Charge totale dans un circuit) #

Le courant étant la charge par unité de temps, on peut écrire
$$
\Delta Q = I \cdot \Delta t = 2.5\cdot 300=750\C.
$$
Nous savons que la charge élémentaire est $e=1.6\cdot 10^{-19}$. On a donc que
$$
\frac{750}{e}\cong 4.7\cdot 10^{21}\mbox{ électrons}.
$$

---

Il existe une convention pas très intuitive pour le sens du courant dans un circuit qu'il vaut la peine de discuter ici. En effet,
le sens du courant est vu comme le déplacement de charges **positives** (bien que ça soit les électrons qui se déplacent). Ainsi, le sens du courant est opposé au sens de déplacement
des électrons (voir @fig:sens_courant).

![Schéma d'un circuit avec le sens du courant conventionnel et le sens de déplacement des électrons.](figs/sens_courant.svg){#fig:sens_courant width=50%}

## La loi d'ohm

La loi d'Ohm relie le courant, $I$, passant dans un circuit à la différence de potentiel qui lui est appliqué. Il s'avère que Ohm détermina que ces deux grandeurs sont proportionnelles (si on double le potentiel on double le courant)
et la constante de proportionnalité est $R$, la *résistance*
$$
V = R\cdot I.
$$
Cette formule est connue sous le petit nom de *Loi d'Ohm*.
Il s'avère que $R$ est indépendante de la tension ou du courant pour des métaux (ce n'est pas le cas pour d'autres types de matériaux comme les diodes, les transistors, etc.).

---

Question (Proportionnalité) #

Si pour un matériau de résistance $R$, nous traçons un graphique du courant $I$ en fonction
de la tension $V$, quelle sera la forme de
la fonction obtenue?

---

---

Réponse (Proportionnalité) #

Comme nous savons que $R$ est une constante,
et que
$$
I=\frac{V}{R},
$$
la fonction sera une droite de pente $1/R$.

---

Les unités de la résistance sont les Ohm, 
notées $\Omega$. Dans un circuit électrique
la résistance est représentée par le symbole de la @fig:resistor

![Symbole de la résistance.](figs/resistor.svg){#fig:resistor width=50%}

---

Question (Que se passe-t-il dans une résistance?) #

Un courant $I$ passe dans une résistance $R$. Soient $A$ et $B$ un point
du circuit avant la résistance et $B$ un point après la résistance.
Est-ce que le potentiel est plus élevé en $A$ ou en $B$? Est-ce
que le courant est plus élevé en $A$ ou en $B$?

---


---

Réponse (Que se passe-t-il dans une résistance?) #

Une charge positive se déplace de `+` à `-` (d'un haut potentiel à un faible potentiel).
Pour reprendre l'analogie avec le potentiel gravitationnel, une masse va se déplacer
d'un haut potentiel gravitationnel à un faible. Ainsi pour un courant positif,
le point $A$ a un potentiel plus élevé que le point $B$. 

Pour le courant en revanche, la conservation de la charge que toute charge entrant
dans la résistance doive en sortir avec le même taux (sinon la charge s'accumulerait,
disparaîtrait, dans la résistance). Le courant n'est ainsi pas consommé à l'intérieur
d'une résistance, tout comme une masse n'est pas consommée lorsqu'elle se déplace dans
un champs gravitationnel.

---

## La puissance électrique

Dans les applications quotidiennes, l'énergie électrique est souvent transformée
en d'autres formes d'énergie: 

* de l'énergie mécanique pour les voitures électriques ou les mixers,
* de l'énergie thermique pour les fours ou les appareils de chauffages.

Dans le cas de corps de chauffe, le processus de chauffage s'obtient car
les électrons entrent en collision avec les atomes du corps de chauffe
et leur transfèrent leur énergie cinétique. Les atomes augmentent ainsi leur énergie
cinétique et la température augmente (on ne va pas entrer dans les détails de comment
cette température est ensuite transférée au reste du monde). 

La puissance électrique, $P$, est l'énergie transformée par unité de temps
$$
P=\frac{\mbox{énergie transformée}}{\mbox{temps}}.
$$

---

Question (Lien potentiel électrique et énergie transformée) #

Quelle est l'énergie transformée par une charge $Q$ se déplaçant dans un champs $V$?

---

---

Réponse (Lien potentiel électrique et énergie transformée) #

On se souvient que le potentiel électrique en un point $A$ est le potentiel l'énergie
potentielle ($E_\mathrm{pot}$) par unité de charge
$$
V(A)=\frac{E_\mathrm{pot}(A)}{Q}.
$$
La différence d'énergie potentielle entre deux points ($A$ et $B$) est donc 
$$
E_\mathrm{pot}(B)-E_\mathrm{pot}(A)=V\cdot Q.
$$

---

Ainsi la puissance électrique est donnée par
$$
P=\frac{QV}{t}.
$$
On se souvient que $I=Q/t$ (la charge déplacée par unité de temps) et on obtient
$$
P=V\cdot I.
$$
A présent, si on veut connaître l'énergie dissipée par unité de temps dans une résistance
$R$ on peut utiliser la fameuse loi d'Ohm ($V=R\cdot I$) et on obtient
$$
P=R\cdot I^2,
$$
ou
$$
P=\frac{V^2}{R}.
$$ 

---

Exemple (Lumière d'automobile) #

Calculer la résistance de l'ampoule de $40\W$ d'une voiture fonctionnant à un
voltage de $12\V$.

---

---

Solution (Lumière d'automobile) #

Connaissant la puissance $P=40\W$ et le voltage $V=12\V$, on peut utiliser
$$
R=\frac{V^2}{P}=\frac{144}{40}=3.6\Omega.
$$

---

Votre facture d'électricité (ou celle de vos parents) est exprimée en kilowatt-heure

---

Question (Kilowatt-heure) #

Est-ce que quelqu'un sait ce que mesure un kilowatt-heure?

---

---

Réponse (Kilowatt-heure) #

Comme son nom l'indique (ou pas) le kilowatt-heure est un kilowatt (donc une puissance) utilisée pendant une heure. C'est donc une puissance multipliée par un temps
ce qui donne une énergie (mesurée en joules). Plus précisément, on a
$$
1 \mathrm{kWh}=1000\cdot 3600=3.6\cdot 10^6\mathrm{J}.
$$

---

---

Exemple (La foudre) #

La foudre est un phénomène naturel très violent qui transfère une énergie
d'environ $10^9\J$ pendant un temps de $0.2\s$. La différence de potentiel
électrique est d'environ $5\cdot 10^7\V$. Avec ces informations estimer
la charge totale transférée entre les nuages et le sol, le courant dans la foudre,
et la puissance moyenne libérée.

---

---

Solution (La foudre) #

Avec l'équation $E_\mathrm{pot}(B)-E_\mathrm{pot}(A)=V\cdot Q$, on peut déduire que
$$
Q=\frac{E_\mathrm{pot}(B)-E_\mathrm{pot}(A)}{V}=20\C.
$$
Le courant est donc donné par
$$
I=\frac{Q}{t}=\frac{20}{0.2}=100\A.
$$
Finalement la puissance est de 
$$
P=\frac{\mbox{énergie}}{\mbox{temps}}=5\cdot 10^9\W.
$$
On voit qu'on obtient le même résultat avec
$$
P=I\cdot V=100\cdot 5\cdot 10^7=5\cdot 10^9\W.
$$
Et c'est une bonne nouvelle.

---

---

Exercice (Chauffage) #

Soit un chauffage portatif dont le voltage de fonctionnement est de $230\V$ et un courant de
$7\A$. Quelle est la puissance nécessaire pour le faire fonctionner? Si le chauffage fonctionne
deux heures par jour et que le coût du kilowatt-heure est de $0.3$ CHF. Quel est le coût total 
mensuel du chauffage portatif?

---

## Le courant alternatif

Lorsqu'une batterie est connectée à un circuit le courant est **continu**: les charges bougent
de façon uniforme dans une seule direction. Le courant qu'on obtient de la part des SIG
est lui **alternatif** (voir @fig:continu_alternatif).

```{.matplotlib #fig:continu_alternatif source=true format=SVG caption="Illustration de courant continu, et de courant alternatif."}
import matplotlib.pyplot as plt
import numpy as np
import math

omega = 3.0
t = np.linspace(0, 2, 500)  # Sample data.

plt.figure(figsize=(5, 2.7), layout='constrained')
plt.plot(t, 0.5*np.ones(t.size), label='continu')  # Plot some data on the (implicit) axes.
plt.plot(t, np.sin(2*math.pi*omega*t), label='alternatif')  # etc.
plt.xlabel('temps [s]')
plt.ylabel('courant [A]')
plt.title("Courant continu/alternatif")
plt.legend()
```

Le courant alternatif modifie la direction du courant plusieurs fois par seconde (environ 6 fois 
par seconde dans le cas de la @fig:continu_alternatif). Le voltage produit par les générateurs
alternatifs dépend du temps et peut être décrit par une fonction sinusoïdale
$$
V(t)=V_0\sin(2\pi f t)=V_0\sin(\omega t),
$$
où le voltage oscille entre $-V_0$ et $V_0$ et est le voltage de pic. La fréquence $f$ est
le nombre d'oscillation par seconde du voltage (en Suisse la fréquence est de $50\mathrm{Hz}$),
 et $\omega=2\pi f$ est la pulsation.

La loi d'Ohm, $V=R\cdot I$, nous permet d'obtenir le courant dans un circuit dont la résistance serait $R$, avec
$$
I(t)=\frac{V(t)}{R}=\frac{V_0}{R}\sin(\omega t)=I_0\sin(\omega t),
$$
où $I_0=V_0/R$ est le courant de pic. On voit ici que le courant peut être positif ou négatif
et donc que les charges se déplacent dans les deux directions.

Le courant comme le voltage alternatif ont une moyenne nulle de voltage et de courant,
cela ne signifie pas que les charges ne transportent pas d'énergie. En effet,
on a pour la puissance
$$
P(t)=I^2(t)\cdot R=I_0^2\cdot R\cdot \sin^2(\omega t).
$$
On voit de ce résultat (voir @fig:puissance_alternatif) que la puissance est **toujours** positive (toutes les grandeurs sont positives dans cette formule). 

```{.matplotlib #fig:puissance_alternatif source=true format=SVG caption="Puissance pour un courant alternatif."}
import matplotlib.pyplot as plt
import numpy as np
import math

omega = 3.0
t = np.linspace(0, 2, 500)  # Sample data.

plt.figure(figsize=(5, 2.7), layout='constrained')
plt.plot(t, 0.5*np.ones(t.size), label='puiss. moy.')  # Plot some data on the (implicit) axes.
plt.plot(t, np.sin(2*math.pi*omega*t)**2, label='puiss. inst.')  # etc.
plt.xlabel('temps [s]')
plt.ylabel('puissance [W]')
plt.title("Puissance instantanée et moyenne du courant alternatif.")
plt.legend()
```

La puissance moyenne, $\bar{P}$, est facilement calculée (on va le faire le calcul ici, mais on le voit bien 
sur l'illustration de @fig:puissance_alternatif) et est donnée par
$$
\bar{P}=\frac{1}{2}I_0^2R=\frac{1}{2}\frac{V_0^2}{R}.
$$

---

Question (Deux cent vingt volts) #

Mais me direz-vous, de quelle tension parlons-nous quand on parle de $230\V$ à Genève? Est-ce la tension moyenne?

---

---

Réponse (Deux cent vingt volts) #

La tension moyenne d'un courant alternatif est nulle (oui la moyenne d'une fonction sinusoïdale est nulle). En revanche on peut calculer la moyenne du carré de la tension (ou du courant respectivement)
\begin{equation}
\overline{V^2}=\frac{1}{2}V_0^2,\quad
\overline{I^2}=\frac{1}{2}I_0^2.
\end{equation}
On va pas voir comment on calcule ce résultat mais c'est assez intuitif, comme le $\sin^2(x)\in [0,1]$ la moyenne doit être la moitié de la valeur maximale du dit sinus.
Afin d'avoir les "bonnes" unités, on voit qu'on doit encore prendre la racine carrée de la moyenne et donc calculer l'écart-type (ou "root-mean-square" en anglais). 
\begin{align}
I_\mathrm{rms}&=\sqrt{\overline{I^2}}=\frac{1}{\sqrt{2}}I_0,\\
V_\mathrm{rms}&=\sqrt{\overline{V^2}}=\frac{1}{\sqrt{2}}V_0.
\end{align}
Ces deux valeurs sont également appelées valeurs de courant et de tension effectives.
Ainsi c'est $V_\mathrm{rms}$ qui est de $230\V$ en Suisse.
Ces deux valeurs permettent également de retrouver la valeur de la puissance moyenne
\begin{align}
\bar{P}&=V_\mathrm{rms}I_\mathrm{rms},\\
\bar{P}&=\frac{1}{2}I_0^2R=I^2_\mathrm{rms}R,\\
\bar{P}&=\frac{1}{2}\frac{V_0^2}{R}=\frac{V^2_\mathrm{rms}}{R}.
\end{align}
Ainsi la tension de pic, $V_0$ est donnée par
\begin{equation}
V_0=\sqrt{2}V_\mathrm{rms}=325\V.
\end{equation}

---

---

Exemple (Sèche-cheveux) #

Calculer la résistance et le courant de pic dans un sèche-cheveux de $1000\W$ branché sur une source de tension de $230\V$. Que se passe-t-il aux USA où la tension est de $120\V$ seulement?

---

---

Solution (Sèche-cheveux) #

De l'équation
\begin{equation*}
\bar{P}=I_\mathrm{rms}V_\mathrm{rms},
\end{equation*}
on obtient
\begin{equation*}
I_\mathrm{rms}=\frac{\bar{P}}{V_\mathrm{rms}}=\frac{1000}{230}=4.35\A.
\end{equation*}
Ainsi le courant de pic est donné par
\begin{equation*}
I_0=\sqrt{2}I_\mathrm{rms}=6.15\A.
\end{equation*}
La résistance est donc donnée par
\begin{equation*}
R=\frac{V_\mathrm{rms}}{I_\mathrm{rms}}=\frac{V_0}{I_0}=\frac{325}{6.15}=52.8\Omega.
\end{equation*}
Aux USA, la tension étant de $120\V$, on obtient pour la puissance $\bar{P}$ disponible
\begin{equation*}
\bar{P}=\frac{V_\mathrm{rms}^2}{R}=\frac{120^2}{52.8}=272\W.
\end{equation*}
On voit qu'on risque d'avoir un problème pour faire fonctionner notre sèche cheveux à plein régime. A l'inverse un sèche-cheveux américain va très probablement griller si on le branche en Europe.

---

